@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -260,7 +260,11 @@ NPError NP_GetValue (G_GNUC_UNUSED void *future, NPPVariable variable, void *val
 	return NPERR_NO_ERROR;
 }
 
+#ifdef MOZILLA_USES_CONST_CHAR
+char const *NP_GetMIMEDescription (void)
+#else
 char *NP_GetMIMEDescription (void)
+#endif
 {
 	return ("chemical/x-xyz:xyz:XYZ Coordinate Format;"
 			"chemical/x-mdl-molfile:mol:MDL Molfile;"
